Re: [PATCH v3 1/3] reset: don't compute unstaged changes after reset when --quiet
- From
Johannes Schindelin <johannes.schindelin@gmx.de>
- Date
- Oct 22, 2018, 20:44 UTC
- Message-ID
- <nycvar.QRO.7.76.6.1810222244150.4546@tvgsbejvaqbjf.bet>
- In-Reply-To
- <20181022131828.21348-2-peartben@gmail.com>
Hi Ben,
On Mon, 22 Oct 2018, Ben Peart wrote:
Show 9 quoted lines
> From: Ben Peart <benpeart@microsoft.com> > > When git reset is run with the --quiet flag, don't bother finding any > additional unstaged changes as they won't be output anyway. This speeds up > the git reset command by avoiding having to lstat() every file looking for > changes that aren't going to be reported anyway. > > The savings can be significant. In a repo with 200K files "git reset" > drops from 7.16 seconds to 0.32 seconds for a savings of 96%.
That's very nice!
Those numbers, just out of curiosity, are they on Windows? Or on Linux?
Ciao, Dscho